
## General

This folder contains scripts to push pm event to the file-ready kafka topic, directly to the topic or via the ves-collector.
For simple testing, pushing directly to the topic is much faster but if integration with e.g. ran simulators; pushing via the ves-collector might be a better option.


## Script - push-genfiles-to-file-ready-topic.sh

This script push generated pm files directly to the file-ready kafka topic.

The script pushes events from one or more RAN nodes. For each RAN node, one or more events are pushed in sequence where each event in the sequence represents a 15 min measurement.
Although each pm-file represents a 15 min measurement period, all events are pushed in a sequence without any delay between the files.
The RAN nodes are specified as a single base name, eg. "NODE-A" and the the script with name the nodes "NODE-A-0", "NODE-A-1" etc.
The event will contain a url to each pm file. These urls points to a web server (simulating a RAN node). The number of web server are fixed so the generated urls are generated so the load is spread out over the web server.

### Parmeters

`push-genfiles-to-file-ready-topic.sh <node-count> <num-of-events> <node-name-base> <file-extension> sftp|ftpes|https <num-servers> [hist]"`

- node-count : The number of simulated RAN nodes
- number-of-events : The number of 15 min measurements (event) per node
- node-name-base : Base name of the RAN nodes, index 0,1,2 etc will be added to the name
- file-extension : The pm file extension - should match the actual pm file to be downloaded from the web-servers (simulated RAN nodes)
- sftp|ftps|https -  Protocol for downloading pm files - only https is currently supported
- num-servers - The number of web servers for pm file download. Should match the number of web servers actually started by the install script. This script generates pm file url to one of the web servers to spread the load. Note that this number can be different from the node-count parameter.
- hist :  By default, each event only contains the reference to a single pm file. If the parameter is given then each event will contain the latest pm file and 95 of the previous file to represent a full 24h set of pm files.


## Script - push-genfiles-to-ves-collector.sh

This script push generated pm files via the ves-collector to the file-ready kafka topic.
The parameter are exactly same as for the `push-genfiles-to-file-ready-topic.sh` script.

## Typical usage

The below example

`<script> 20 100 GNODEB xml.gz https 10`

This will push 100 events (file ready events) for each of the 20 nodes. The timestamp of the first files for the 20 node will be as configured in this script. Each following events will have a timestamp of 15 minutes later.
The nodes will be named `GNODEB-0 -- GNODEB-19`.
The file format of the file url will use xml.gz (the corresponding files are expected to exist or be generated by the server url).
Files will be downloaded by the datafile collector using https.
The ranpm is setup with 10 https servers (ran simulators) where the files will be downloaded. Note that this number should be equal to or less than the number of https servers.

The following file names will be present in the sequence of events - a total of 200 event (20 *100):

`A20230515.0700+0100-0715+0100_GNODEB-0.xml.gz`
`A20230515.0700+0100-0715+0100_GNODEB-1.xml.gz` \
`...`\
`A20230516.0745+0100-0800+0100_GNODEB-18.xml.gz`
`A20230516.0745+0100-0800+0100_GNODEB-19.xml.gz`



## License

Copyright (C) 2023 Nordix Foundation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.